import { HttpCache } from '../contracts/http-cache.js';
import { HttpInterceptor } from '../contracts/http-interceptor.js';
import { HttpParams, Http } from '../contracts/http-params.js';
import { HttpClientProps } from '../contracts/http-client-props.js';
import { HttpRequestClient, HttpRequest } from '../contracts/http-request.js';
import { HttpResponse } from '../contracts/http-response.js';
import { HttpClient } from '../contracts/verbs/http-client.js';
import { HttpGet } from '../contracts/verbs/http-get-client.js';
import { HttpDelete } from '../contracts/verbs/http-delete-client.js';
import { HttpPatch } from '../contracts/verbs/http-patch-client.js';
import { HttpPost } from '../contracts/verbs/http-post-client.js';
import { HttpPut } from '../contracts/verbs/http-put-client.js';
import '../contracts/http-headers.js';

type Interceptor = {
    id: number;
    name: string;
};
type Interceptors = {
    request: Interceptor[];
    response: Interceptor[];
};
declare class SuperHttpClientAdapter implements HttpClientProps, HttpParams, HttpInterceptor, HttpClient, HttpRequestClient {
    private readonly _timeout;
    private readonly _interceptors;
    private readonly cache;
    private readonly instance;
    constructor({ baseURL, timeout }: HttpClientProps, cache?: HttpCache.Input & {
        storage: HttpCache.Storage;
    });
    get baseURL(): string;
    set baseURL(baseURL: string);
    get timeout(): number;
    get interceptors(): Interceptors;
    private makeStorageFromDriver;
    private resolveURL;
    private buildHttpSuccessResponse;
    resolveRouteParams(input: Http.RouteInput): Http.RouteOutput;
    resolveQueryParams(input: Http.QueryInput): Http.QueryOutput;
    useInterceptor({ type, name, success, error }: HttpInterceptor.UseInput): void;
    ejectInterceptor({ type, name }: HttpInterceptor.EjectInput): void;
    clearAllInterceptors({ type }: HttpInterceptor.ClearInput): void;
    get<R = any>(input: HttpGet.Input, cache?: HttpCache.Props | false): Promise<HttpResponse<R>>;
    post<D = any, R = any>(input: HttpPost.Input<D>, cache?: HttpCache.Props | false): Promise<HttpResponse<R>>;
    patch<D = any, R = any>(input: HttpPatch.Input<D>, cache?: HttpCache.Props | false): Promise<HttpResponse<R>>;
    put<D = any, R = any>(input: HttpPut.Input<D>, cache?: HttpCache.Props | false): Promise<HttpResponse<R>>;
    delete<D = any, R = any>(input: HttpDelete.Input, cache?: HttpCache.Props | false): Promise<HttpResponse<R>>;
    request<D = any, R = any>(input: HttpRequest.Input<D>, cache?: HttpCache.Props | false): Promise<HttpResponse<R>>;
}

export { SuperHttpClientAdapter };
